@@ -66,7 +66,8 @@
         $.getJSON(options.lookup_url, {
             object_id: elem.val(),
             app_label: grappelli.get_app_label(elem),
-            model_name: grappelli.get_model_name(elem)
+            model_name: grappelli.get_model_name(elem),
+            query_string: grappelli.get_query_string(elem)
         }, function(data) {
             if (data[0].label === "") {
                 text.hide();
